import chalk from "chalk";
import commandLineUsage from "command-line-usage";
import { stringSorter, taskSorter } from "./utils.js";
export function formatTasks(format, tasks, defaultTask) {
    tasks = tasks
        .slice(0)
        .filter((task) => !task.options.hiddenFromTaskList)
        .sort(taskSorter);
    if (format === "simple") {
        return tasks.map((task) => task.options.name).join("\n");
    }
    const sections = [];
    sections.push({
        header: "Available tasks",
        content: tasks.map((task) => {
            var _a;
            const name = task !== defaultTask
                ? chalk.blue(task.options.name)
                : `${chalk.green(task.options.name)} (default)`;
            const descriptionParts = [];
            if (task.options.description) {
                descriptionParts.push(task.options.description);
            }
            const deps = (_a = task.options.dependencies) === null || _a === void 0 ? void 0 : _a.filter((task) => !task.options.hiddenFromTaskList);
            if (deps && deps.length > 0) {
                const depNames = deps
                    .map((task) => task.options.name)
                    .sort(stringSorter)
                    .map((v) => chalk.blue(v));
                descriptionParts.push(`Depends on: ${depNames.join(", ")}`);
            }
            return { name, description: descriptionParts.join("\n") };
        }),
    });
    return commandLineUsage(sections);
}
//# sourceMappingURL=formatTasks.js.map